SlimFit
=======


**SymFit's little brother**


This project is inspired by [SymFit](https://github.com/tBuLi/symfit) and is functional, to some degree, but in currently in BETA

* Free software: MIT license
* Documentation: For the moment please refer to the `examples` folder.


Aims
----

* Inspiration for a potential SymFit 2.0
* Expectation-Maximization likelihood maximization

Installation
------------

Currently not on PyPi or conda-forge, but you can install and give it a try from source.
